==> pipewire-0.1.7-1-aarch64.pkg.tar.xz: usr/share/doc/pipewire/html/protocol_8h.js <==
var protocol_8h =
[
    [ "pw_protocol_client", "structpw__protocol__client.html", "structpw__protocol__client" ],
    [ "pw_protocol_server", "structpw__protocol__server.html", "structpw__protocol__server" ],
    [ "pw_protocol_marshal", "structpw__protocol__marshal.html", "structpw__protocol__marshal" ],
    [ "pw_protocol_implementaton", "structpw__protocol__implementaton.html", "structpw__protocol__implementaton" ],
    [ "pw_protocol_events", "structpw__protocol__events.html", "structpw__protocol__events" ],
    [ "pw_protocol_add_server", "protocol_8h.html#a3b9d1f2afdf848863a84c7f2c825dc32", null ],
    [ "pw_protocol_client_connect", "protocol_8h.html#a149518dd7ca9a235eddca90ed2e38f75", null ],
    [ "pw_protocol_client_connect_fd", "protocol_8h.html#afc4c44c0db62c2c03886901ef6f7a4fd", null ],
    [ "pw_protocol_client_destroy", "protocol_8h.html#ad3a30029abadec4f4b76ae2cb28a4585", null ],
    [ "pw_protocol_client_disconnect", "protocol_8h.html#a6673120bfc643d6cbeea97535873b4f0", null ],
    [ "pw_protocol_ext", "protocol_8h.html#a91126ea5ca35fb743c9fd04d27316fe1", null ],
    [ "pw_protocol_new_client", "protocol_8h.html#a10397b3ea74c80703140242313ab52df", null ],
    [ "pw_protocol_server_destroy", "protocol_8h.html#a6c57711ce8eee785b967ed0487a2fe3b", null ],
    [ "PW_TYPE__Protocol", "protocol_8h.html#a1667bbb761ac038884e0b08b3ad0113a", null ],
    [ "PW_TYPE_PROTOCOL_BASE", "protocol_8h.html#a7ec159e0c7c93a0ba25f391fc828b4cf", null ],
    [ "PW_VERSION_PROTOCOL_EVENTS", "protocol_8h.html#ac2742efc503c7a6e04238bd9a94af35e", null ],
    [ "PW_VERSION_PROTOCOL_IMPLEMENTATION", "protocol_8h.html#a4d8f6852ba390ba826744d18b58c4021", null ],
    [ "pw_core_find_protocol", "protocol_8h.html#ab10469364d146903d93e85a936a933bb", null ],
    [ "pw_protocol_add_listener", "protocol_8h.html#a253136c71f02f82d59fd79c78c40fe65", null ],
    [ "pw_protocol_add_marshal", "protocol_8h.html#a05392f10789927043f44d78d56b14f7f", null ],
    [ "pw_protocol_destroy", "protocol_8h.html#a6d58875f54dbf541b969c5911b802311", null ],
    [ "pw_protocol_get_extension", "protocol_8h.html#aedaad565d0021ebcffe1b8699d150174", null ],
    [ "pw_protocol_get_implementation", "protocol_8h.html#ae14bc734b0ea2f0cd081716a552d3b07", null ],
    [ "pw_protocol_get_marshal", "protocol_8h.html#a0dac7c46c3ffea078e00f23ba75edf80", null ],
    [ "pw_protocol_get_user_data", "protocol_8h.html#aaba33660d98b865fb0ea4898ab6f8fe8", null ],
    [ "pw_protocol_new", "protocol_8h.html#a515ef2ac9a2e741b04e3301573c7468e", null ]
];

==> pipewire-0.1.8-1-aarch64.pkg.tar.xz: usr/share/doc/pipewire/html/protocol_8h.js <==
var protocol_8h =
[
    [ "pw_protocol_client", "structpw__protocol__client.html", "structpw__protocol__client" ],
    [ "pw_protocol_server", "structpw__protocol__server.html", "structpw__protocol__server" ],
    [ "pw_protocol_marshal", "structpw__protocol__marshal.html", "structpw__protocol__marshal" ],
    [ "pw_protocol_implementaton", "structpw__protocol__implementaton.html", "structpw__protocol__implementaton" ],
    [ "pw_protocol_events", "structpw__protocol__events.html", "structpw__protocol__events" ],
    [ "pw_protocol_add_server", "protocol_8h.html#a3b9d1f2afdf848863a84c7f2c825dc32", null ],
    [ "pw_protocol_client_connect", "protocol_8h.html#a149518dd7ca9a235eddca90ed2e38f75", null ],
    [ "pw_protocol_client_connect_fd", "protocol_8h.html#afc4c44c0db62c2c03886901ef6f7a4fd", null ],
    [ "pw_protocol_client_destroy", "protocol_8h.html#ad3a30029abadec4f4b76ae2cb28a4585", null ],
    [ "pw_protocol_client_disconnect", "protocol_8h.html#a6673120bfc643d6cbeea97535873b4f0", null ],
    [ "pw_protocol_client_steal_fd", "protocol_8h.html#aeae48475b735761c22837afd53e2ce9e", null ],
    [ "pw_protocol_ext", "protocol_8h.html#a91126ea5ca35fb743c9fd04d27316fe1", null ],
    [ "pw_protocol_new_client", "protocol_8h.html#a10397b3ea74c80703140242313ab52df", null ],
    [ "pw_protocol_server_destroy", "protocol_8h.html#a6c57711ce8eee785b967ed0487a2fe3b", null ],
    [ "PW_TYPE__Protocol", "protocol_8h.html#a1667bbb761ac038884e0b08b3ad0113a", null ],
    [ "PW_TYPE_PROTOCOL_BASE", "protocol_8h.html#a7ec159e0c7c93a0ba25f391fc828b4cf", null ],
    [ "PW_VERSION_PROTOCOL_EVENTS", "protocol_8h.html#ac2742efc503c7a6e04238bd9a94af35e", null ],
    [ "PW_VERSION_PROTOCOL_IMPLEMENTATION", "protocol_8h.html#a4d8f6852ba390ba826744d18b58c4021", null ],
    [ "pw_core_find_protocol", "protocol_8h.html#ab10469364d146903d93e85a936a933bb", null ],
    [ "pw_protocol_add_listener", "protocol_8h.html#a253136c71f02f82d59fd79c78c40fe65", null ],
    [ "pw_protocol_add_marshal", "protocol_8h.html#a4b8a7c184d8756e4864538f16a60bec3", null ],
    [ "pw_protocol_destroy", "protocol_8h.html#a6d58875f54dbf541b969c5911b802311", null ],
    [ "pw_protocol_get_extension", "protocol_8h.html#aedaad565d0021ebcffe1b8699d150174", null ],
    [ "pw_protocol_get_implementation", "protocol_8h.html#ae14bc734b0ea2f0cd081716a552d3b07", null ],
    [ "pw_protocol_get_marshal", "protocol_8h.html#a0dac7c46c3ffea078e00f23ba75edf80", null ],
    [ "pw_protocol_get_user_data", "protocol_8h.html#aaba33660d98b865fb0ea4898ab6f8fe8", null ],
    [ "pw_protocol_new", "protocol_8h.html#a515ef2ac9a2e741b04e3301573c7468e", null ]
];
